==> opencity_0.0.4stable.orig.tar.gz: opencity-0.0.4stable/src/model/ac3dmacros.h <==
/***************************************************************************
							AC3DMacros.h  -  description
								-------------------
	begin                : mer juin 30 05
	copyright            : (C) 2005 by Duong-Khang NGUYEN
	email                : neoneurone @ users sourceforge net
	
	$Id: ac3dmacros.h 42 2006-09-10 16:03:31Z neoneurone $
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   any later version.                                                    *
 *                                                                         *
 ***************************************************************************/
 
#ifndef _OPENCITY_AC3DAC3DMACROS_H_
#define _OPENCITY_AC3DAC3DMACROS_H_ 1

#define	AC3D_TOKEN_MATERIAL		"MATERIAL"
#define	AC3D_TOKEN_MATERIAL_L	8
#define	AC3D_TOKEN_OBJECT		"OBJECT"
#define	AC3D_TOKEN_OBJECT_L		6
#define	AC3D_TOKEN_KIDS			"kids"
#define	AC3D_TOKEN_KIDS_L		4
#define AC3D_MAX_LINE_LENGTH	1024
#define AC3D_TOKEN_NAME			"name"
#define AC3D_TOKEN_NAME_L		4
#define AC3D_TOKEN_TEXTURE		"texture"
#define AC3D_TOKEN_TEXTURE_L	7
#define AC3D_TOKEN_TEXREP		"texrep"
#define AC3D_TOKEN_TEXREP_L		6
#define AC3D_TOKEN_ROT			"rot"
#define AC3D_TOKEN_ROT_L		3
#define AC3D_TOKEN_LOC			"loc"
#define AC3D_TOKEN_LOC_L		3
#define AC3D_TOKEN_CREASE		"crease"
#define AC3D_TOKEN_CREASE_L		6
#define AC3D_TOKEN_URL			"url"
#define AC3D_TOKEN_URL_L		3
#define AC3D_TOKEN_NUMVERT		"numvert"
#define AC3D_TOKEN_NUMVERT_L	7
#define AC3D_TOKEN_NUMSURF		"numsurf"
#define AC3D_TOKEN_NUMSURF_L	7
#define AC3D_TOKEN_SURF			"SURF"
#define AC3D_TOKEN_SURF_L		4
#define AC3D_TOKEN_MAT			"mat"
#define AC3D_TOKEN_MAT_L		3
#define AC3D_TOKEN_REFS			"refs"
#define AC3D_TOKEN_REFS_L		4

#endif

==> opencity_0.0.5.1stable.orig.tar.gz: opencity-0.0.5stable/src/model/ac3dmacros.h <==
/***************************************************************************
						AC3DMacros.h  -  description
							-------------------
	begin                : june 30th, 05
	copyright            : (C) 2005-2007 by Duong-Khang NGUYEN
	email                : neoneurone @ users sourceforge net
	
	$Id: ac3dmacros.h 121 2007-01-09 20:53:17Z neoneurone $
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   any later version.                                                    *
 *                                                                         *
 ***************************************************************************/
 
#ifndef _OPENCITY_AC3DAC3DMACROS_H_
#define _OPENCITY_AC3DAC3DMACROS_H_ 1

#define AC3D_MAX_LINE_LENGTH	1024


//========================================================================
// AC3D commands
//========================================================================

#define AC3D_TOKEN_MATERIAL		"MATERIAL"
#define AC3D_TOKEN_MATERIAL_L	8

#define AC3D_TOKEN_OBJECT		"OBJECT"
#define AC3D_TOKEN_OBJECT_L		6
#define AC3D_TOKEN_KIDS			"kids"
#define AC3D_TOKEN_KIDS_L		4
#define AC3D_TOKEN_NAME			"name"
#define AC3D_TOKEN_NAME_L		4
#define AC3D_TOKEN_DATA			"data"
#define AC3D_TOKEN_DATA_L		4
#define AC3D_TOKEN_TEXTURE		"texture"
#define AC3D_TOKEN_TEXTURE_L	7
#define AC3D_TOKEN_TEXREP		"texrep"
#define AC3D_TOKEN_TEXREP_L		6
#define AC3D_TOKEN_ROT			"rot"
#define AC3D_TOKEN_ROT_L		3
#define AC3D_TOKEN_LOC			"loc"
#define AC3D_TOKEN_LOC_L		3
#define AC3D_TOKEN_CREASE		"crease"
#define AC3D_TOKEN_CREASE_L		6
#define AC3D_TOKEN_URL			"url"
#define AC3D_TOKEN_URL_L		3
#define AC3D_TOKEN_NUMVERT		"numvert"
#define AC3D_TOKEN_NUMVERT_L	7
#define AC3D_TOKEN_NUMSURF		"numsurf"
#define AC3D_TOKEN_NUMSURF_L	7

#define AC3D_TOKEN_SURF			"SURF"
#define AC3D_TOKEN_SURF_L		4
#define AC3D_TOKEN_MAT			"mat"
#define AC3D_TOKEN_MAT_L		3
#define AC3D_TOKEN_REFS			"refs"
#define AC3D_TOKEN_REFS_L		4


//========================================================================
// OpenCity AC3D commands
//========================================================================

#define OC_AC3D_TOKEN_ALPHA		"alpha"
#define OC_AC3D_TOKEN_ALPHA_L	5


#endif
